@@ -11,8 +11,8 @@ def f(directory, filepaths=[]):
   if not exists(directory): return
 
   for item in listdir(directory):
-    π = directory+'/'+item
-    f(π, filepaths) if isdir(π) else remove(π)
+    _pi = directory+'/'+item
+    f(_pi, filepaths) if isdir(_pi) else remove(_pi)
 
   rmdir(directory)
 
