@@ -1,3 +1,3 @@
 from jft.string.format import f as format_one
-f = lambda λ, fn=format_one: [fn(π) for π in λ]
+f = lambda _l, fn=format_one: [fn(_pi) for _pi in _l]
 t = lambda: list('abc') == f(list('abc'), lambda x: x)
\ No newline at end of file
