@@ -3,8 +3,8 @@ from jft.directory.list_pyfilepaths import f as list_py_files
 from jft.strings.pyfiles.filter_out_items import f as filter_out_items
 from jft.pyfiles.format import f as auto_format_py_filenames
 
-def f(Λ_π, fn_a=auto_format_py_filenames, fn_b=push_commits_after_delay):
-  a = fn_a(Λ_π)
+def f(_L_pi, fn_a=auto_format_py_filenames, fn_b=push_commits_after_delay):
+  a = fn_a(_L_pi)
   b = fn_b(5)
   return a, b
 
