@@ -9,7 +9,7 @@
   'f = lambda',
 ]
 
-f = lambda x: any([λ.startswith(γ) for γ in Γ for λ in x.split('\n')])
+f = lambda x: any([_l.startswith(γ) for γ in Γ for _l in x.split('\n')])
 
 t = lambda: all([
   f("f = lambda x:"), not f("t = lambda:"),
