@@ -1,10 +1,10 @@
-from jft.string.contains.λ import f as contains_lambda
+from jft.string.contains.l import f as contains_lambda
 
 def f(x):
-  lines_containing_lambda = [λ for λ in x.split('\n') if contains_lambda(λ)]
+  lines_containing_lambda = [_l for _l in x.split('\n') if contains_lambda(_l)]
   if lines_containing_lambda:
-    for λ in lines_containing_lambda:
-      x = x.replace(λ, '\n'+λ)
+    for _l in lines_containing_lambda:
+      x = x.replace(_l, '\n'+_l)
     return x
   else:
     return x
