@@ -1,8 +1,8 @@
 from jft.text_colours.info import f as info
 from jft.string.hbar.make import f as hbar
 
-f = lambda π_filename, content_without_function: '\n'.join([
-  info(f'{π_filename} content_without_function:'),
+f = lambda _pi_filename, content_without_function: '\n'.join([
+  info(f'{_pi_filename} content_without_function:'),
   content_without_function,
   hbar()
 ])
