@@ -4,9 +4,9 @@ from jft.strings.two_char_combinations import f as prepare_combinations
 def f(original):
   data = original
   chars = ''.join(sorted(list(set(data))))
-  Λ = prepare_combinations(chars)
-  for λ in Λ:
-    candidate_data = data.replace(λ, '')
+  _L = prepare_combinations(chars)
+  for _l in _L:
+    candidate_data = data.replace(_l, '')
 
     if len(candidate_data) < len(data):
       _raw_result = sprun(
