@@ -1,7 +1,9 @@
 from jft.pip.version.to_str import f as make_v_str
 from jft.string.contains.version import f as k
 
-f = lambda v, Λ: [(f"  version='{make_v_str(v)}'," if k(λ) else λ) for λ in Λ]
+f = lambda v, _L: [
+  (f"  version='{make_v_str(v)}'," if k(_l) else _l) for _l in _L
+]
 
 v = {'major': 4, 'minor': 5, 'patch': 6}
 
