@@ -7,10 +7,10 @@ from jft.directory.remove import f as remove_dir
 f = lambda x: {φ: load(φ) for φ in x}
 
 _root = '../temp_pyfiles_to_dict'
-_Π = [(f'{_root}/foo.py', 'foo'), (f'{_root}/bar.py', 'bar')]
+_Pi = [(f'{_root}/foo.py', 'foo'), (f'{_root}/bar.py', 'bar')]
 
-tear_down = lambda: [*[remove(π_f) for (π_f, _) in _Π], remove_dir(_root)]
-setup = lambda: [mkdir(_root), *[save(π_f, π_d) for π_f, π_d in _Π]]
+tear_down = lambda: [*[remove(_pi_f) for (_pi_f, _) in _Pi], remove_dir(_root)]
+setup = lambda: [mkdir(_root), *[save(_pi_f, _pi_d) for _pi_f, _pi_d in _Pi]]
 
 def t():
   setup()
